@@ -11,7 +11,6 @@
   Added the ability to recursively compare dictionaries
 """
 import collections.abc as abc
-import copy
 from typing import Any
 from typing import Dict
 from typing import List
@@ -340,8 +339,8 @@ class RecursiveDictDiffer(DictDiffer):
 def deep_diff(old: Dict, new: Dict, ignore: List = None) -> Dict[str, Any]:
     ignore = ignore or []
     res = {}
-    old = copy.deepcopy(old) or {}
-    new = copy.deepcopy(new) or {}
+    old = {k: v for k, v in old.items()}
+    new = {k: v for k, v in new.items()}
 
     stack = [(old, new, False)]
 
